@@ -1,4 +1,4 @@
-# Copyright 2021 BlueCat Networks (USA) Inc. and its affiliates.
+# Copyright 2021-2022 BlueCat Networks (USA) Inc. and its affiliates.
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 """Models representing all Address Manager object types supported in the API."""
@@ -246,11 +246,19 @@ class UDLDefinition(dict):
     Model for the structure describing User-Defined Link definitions used by
     Address Manager's API.
 
+    .. note:: Starting from Address Manager v9.4.0, the option **description** is supported.
+
+        * The maximum length of this field is 512 characters.
+        * If the **description** field is not specified, it will be null.
+        * On upgrading from Address Manager v9.3.0, the **description** for the existing links will
+          be populated as **null**.
+
     :key linkType: The UDL's unique name. Value type is str. Cannot be a reserved link type name
         and cannot start with "BCN\\_".
     :key displayName: The UDL's name as displayed in BAM. Value type is str.
     :key sourceEntityTypes: The UDL's source entity types. Value type is list[str].
     :key destinationEntityTypes: The UDL's destination entity types. Value type is list[str].
+    :key description: (Optional) The description for the user-defined link.
     """
 
     # NOTE: The use of '\\_' in the above docstring is intentional. The goal is 2 level escaping:
@@ -283,9 +291,15 @@ class UDLRelationship(dict):
     Model for the structure describing User-Defined Link relationships used by
     Address Manager's API.
 
+    .. note:: Starting from Address Manager v9.4.0, the option **description** and
+        **destinationEntityIds** are supported.
+
     :key linkType: The UDL's link type. Value type is str.
     :key sourceEntityId: The UDL's source entity ID. Value type is int.
+    :key description: (optional) The description for the user-defined link.
     :key destinationEntityId: (Optional) The UDL's destination entity ID. Value type is int.
+    :key destinationEntityIds: (Optional) The list of UDL's destination entity ID, comma-separated
+        inside square brackets.
     """
 
     @staticmethod
